@@ -11,13 +11,6 @@ try:
 except ImportError:
     version = 'unknown'
 
-# Uncomment the following line to treat all DeprecationWarnings as
-# exceptions
-# NOTE: socks warning fixed by https://github.com/Anorov/PySocks/pull/106
-#       but not released yet.
-from astropy.tests.helper import enable_deprecations_as_exceptions
-enable_deprecations_as_exceptions(warnings_to_ignore_entire_module=['socks'])
-
 # Uncomment and customize the following lines to add/remove entries
 # from the list of packages for which version numbers are displayed
 # when running the tests.
